@@ -4,6 +4,7 @@ import json
 import uuid
 from datetime import timedelta
 
+import django
 from django import forms
 from django.conf import settings
 from django.contrib import messages
@@ -158,12 +159,19 @@ class AccountTests(TestCase):
                 "password2": "janedoe",
             },
         )
-        self.assertFormError(
-            resp,
-            "form",
-            "password2",
-            "You must type the same password each time.",
-        )
+        if django.VERSION >= (4, 1):
+            self.assertFormError(
+                resp.context["form"],
+                "password2",
+                "You must type the same password each time.",
+            )
+        else:
+            self.assertFormError(
+                resp,
+                "form",
+                "password2",
+                "You must type the same password each time.",
+            )
 
     @override_settings(
         ACCOUNT_USERNAME_REQUIRED=True, ACCOUNT_SIGNUP_EMAIL_ENTER_TWICE=True
@@ -317,7 +325,7 @@ class AccountTests(TestCase):
 
         reset_pass_url = resp.url
 
-        # Accesing the url via a different session
+        # Accessing the url via a different session
         resp = self.client_class().get(reset_pass_url)
 
         # We should receive the token_fail context_data
@@ -507,7 +515,7 @@ class AccountTests(TestCase):
             )
             # is_active is controlled by the admin to manually disable
             # users. I don't want this flag to flip automatically whenever
-            # users verify their email adresses.
+            # users verify their email addresses.
             self.assertTrue(
                 get_user_model()
                 .objects.filter(username="johndoe", is_active=True)
@@ -598,14 +606,23 @@ class AccountTests(TestCase):
                     "password": ("doe" if is_valid_attempt else "wrong"),
                 },
             )
-            self.assertFormError(
-                resp,
-                "form",
-                None,
-                "Too many failed login attempts. Try again later."
-                if is_locked
-                else "The username and/or password you specified are not correct.",
-            )
+            if django.VERSION >= (4, 1):
+                self.assertFormError(
+                    resp.context["form"],
+                    None,
+                    "Too many failed login attempts. Try again later."
+                    if is_locked
+                    else "The username and/or password you specified are not correct.",
+                )
+            else:
+                self.assertFormError(
+                    resp,
+                    "form",
+                    None,
+                    "Too many failed login attempts. Try again later."
+                    if is_locked
+                    else "The username and/or password you specified are not correct.",
+                )
 
     @override_settings(
         ACCOUNT_AUTHENTICATION_METHOD=app_settings.AuthenticationMethod.EMAIL,
@@ -628,22 +645,36 @@ class AccountTests(TestCase):
         resp = self.client.post(
             reverse("account_login"), {"login": user.email, "password": "bad"}
         )
-        self.assertFormError(
-            resp,
-            "form",
-            None,
-            "The e-mail address and/or password you specified are not correct.",
-        )
+        if django.VERSION >= (4, 1):
+            self.assertFormError(
+                resp.context["form"],
+                None,
+                "The e-mail address and/or password you specified are not correct.",
+            )
+        else:
+            self.assertFormError(
+                resp,
+                "form",
+                None,
+                "The e-mail address and/or password you specified are not correct.",
+            )
 
         resp = self.client.post(
             reverse("account_login"), {"login": user.email, "password": "bad"}
         )
-        self.assertFormError(
-            resp,
-            "form",
-            None,
-            "Too many failed login attempts. Try again later.",
-        )
+        if django.VERSION >= (4, 1):
+            self.assertFormError(
+                resp.context["form"],
+                None,
+                "Too many failed login attempts. Try again later.",
+            )
+        else:
+            self.assertFormError(
+                resp,
+                "form",
+                None,
+                "Too many failed login attempts. Try again later.",
+            )
 
         self.client.post(reverse("account_reset_password"), data={"email": user.email})
 
@@ -904,13 +935,21 @@ class AccountTests(TestCase):
                 "password2": "johndoe",
             },
         )
-        self.assertFormError(resp, "form", None, [])
-        self.assertFormError(
-            resp,
-            "form",
-            "password1",
-            ["This password is too short. It must contain at least 9 characters."],
-        )
+        if django.VERSION >= (4, 1):
+            self.assertFormError(resp.context["form"], None, [])
+            self.assertFormError(
+                resp.context["form"],
+                "password1",
+                ["This password is too short. It must contain at least 9 characters."],
+            )
+        else:
+            self.assertFormError(resp, "form", None, [])
+            self.assertFormError(
+                resp,
+                "form",
+                "password1",
+                ["This password is too short. It must contain at least 9 characters."],
+            )
 
     @override_settings(ACCOUNT_EMAIL_CONFIRMATION_HMAC=True)
     def test_email_confirmation_hmac_falls_back(self):
@@ -1051,6 +1090,35 @@ class AccountTests(TestCase):
         actual_message = msgs._queued_messages[0].message
         assert user.username in actual_message, actual_message
 
+    @override_settings(
+        ACCOUNT_PREVENT_ENUMERATION=True,
+        ACCOUNT_AUTHENTICATION_METHOD=app_settings.AuthenticationMethod.EMAIL,
+        ACCOUNT_EMAIL_VERIFICATION=app_settings.EmailVerificationMethod.MANDATORY,
+    )
+    def test_prevent_account_enumeration_at_signup(self):
+        user = get_user_model().objects.create_user(
+            username="john", email="john@example.org", password="doe"
+        )
+        EmailAddress.objects.create(
+            user=user, email=user.email, primary=True, verified=True
+        )
+        c = Client()
+        # Signup
+        resp = c.post(
+            reverse("account_signup"),
+            {
+                "username": "johndoe",
+                "email": user.email,
+                "password1": "johndoe",
+                "password2": "johndoe",
+            },
+        )
+        self.assertEqual(resp.status_code, 302)
+        assert resp["location"] == reverse("account_email_verification_sent")
+        self.assertTemplateUsed(
+            resp, "account/email/account_already_exists_message.txt"
+        )
+
 
 class EmailFormTests(TestCase):
     def setUp(self):
@@ -1191,7 +1259,7 @@ class EmailFormTests(TestCase):
             reverse("account_email"),
             {"action_send": "", "email": "email@unknown.org"},
         )
-        # This unkown email address must not be implicitly added.
+        # This unknown email address must not be implicitly added.
         assert EmailAddress.objects.filter(user=self.user).count() == 2
 
     @override_settings(ACCOUNT_MAX_EMAIL_ADDRESSES=2)
