@@ -150,7 +150,7 @@ class DefaultSocialAccountAdapter(object):
                         # Oops, another user already has this address.
                         # We cannot simply connect this social account
                         # to the existing user. Reason is that the
-                        # email adress may not be verified, meaning,
+                        # email address may not be verified, meaning,
                         # the user may be a hacker that has added your
                         # email address to their account in the hope
                         # that you fall in their trap.  We cannot
@@ -191,11 +191,11 @@ class DefaultSocialAccountAdapter(object):
     def serialize_instance(self, instance):
         return serialize_instance(instance)
 
-    def get_app(self, request, provider):
+    def get_app(self, request, provider, config=None):
         # NOTE: Avoid loading models at top due to registry boot...
         from allauth.socialaccount.models import SocialApp
 
-        config = app_settings.PROVIDERS.get(provider, {}).get("APP")
+        config = config or app_settings.PROVIDERS.get(provider, {}).get("APP")
         if config:
             app = SocialApp(provider=provider)
             for field in ["client_id", "secret", "key", "certificate_key"]:
