@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 import json
 import requests
 
+from allauth.socialaccount import app_settings
 from allauth.socialaccount.providers.oauth2.client import OAuth2Error
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
@@ -34,34 +35,38 @@ def _check_errors(response):
 class MicrosoftGraphOAuth2Adapter(OAuth2Adapter):
     provider_id = MicrosoftGraphProvider.id
 
-    def __init__(self, request):
-        super(MicrosoftGraphOAuth2Adapter, self).__init__(request)
-        provider = self.get_provider()
-        tenant = provider.get_settings().get("tenant") or "common"
-        user_properties = (
-            "businessPhones",
-            "displayName",
-            "givenName",
-            "id",
-            "jobTitle",
-            "mail",
-            "mobilePhone",
-            "officeLocation",
-            "preferredLanguage",
-            "surname",
-            "userPrincipalName",
-            "mailNickname",
-        )
-        base_url = "https://login.microsoftonline.com/{0}".format(tenant)
-        self.access_token_url = "{0}/oauth2/v2.0/token".format(base_url)
-        self.authorize_url = "{0}/oauth2/v2.0/authorize".format(base_url)
-        self.profile_url = "https://graph.microsoft.com/v1.0/me/"
-        self.profile_url_params = {"$select": ",".join(user_properties)}
+    settings = app_settings.PROVIDERS.get(provider_id, {})
+    # Lower case "tenant" for backwards compatibility
+    tenant = settings.get("TENANT", settings.get("tenant", "common"))
+
+    provider_base_url = "https://login.microsoftonline.com/{0}".format(tenant)
+    access_token_url = "{0}/oauth2/v2.0/token".format(provider_base_url)
+    authorize_url = "{0}/oauth2/v2.0/authorize".format(provider_base_url)
+    profile_url = "https://graph.microsoft.com/v1.0/me"
+
+    user_properties = (
+        "businessPhones",
+        "displayName",
+        "givenName",
+        "id",
+        "jobTitle",
+        "mail",
+        "mobilePhone",
+        "officeLocation",
+        "preferredLanguage",
+        "surname",
+        "userPrincipalName",
+        "mailNickname",
+        "companyName",
+    )
+    profile_url_params = {"$select": ",".join(user_properties)}
 
     def complete_login(self, request, app, token, **kwargs):
         headers = {"Authorization": "Bearer {0}".format(token.token)}
         response = requests.get(
-            self.profile_url, self.profile_url_params, headers=headers
+            self.profile_url,
+            params=self.profile_url_params,
+            headers=headers,
         )
         extra_data = _check_errors(response)
         return self.get_provider().sociallogin_from_response(request, extra_data)
